import { Link, useLocation } from "wouter";
import {
  MessageSquare,
  Code2,
  Search,
  TrendingUp,
  Bot,
  ShieldCheck,
  ArrowRight,
  Image,
  ImageOff,
  Award
} from "lucide-react";
import { Button } from "@/components/ui/button";
import { Card } from "@/components/ui/card";
import { TooltipProvider, Tooltip, TooltipTrigger, TooltipContent } from "@/components/ui/tooltip";
import { Footer } from "@/components/ui/footer";
import { Header } from "@/components/ui/header";
import { type ModelType } from "@shared/schema";

const tools = [
  {
    title: "Private Chat",
    icon: <MessageSquare className="h-6 w-6" />,
    description: "Secure AI chat with end-to-end encryption",
    path: "/private-chat",
    model: "gpt-4o-2024-11-20",
    available: true
  },
  {
    title: "Code Generator",
    icon: <Code2 className="h-6 w-6" />,
    description: "Generate quality code with AI assistance",
    path: "/code-generator",
    model: "claude-3-5-sonnet-20241022",
    available: true
  },
  {
    title: "Text to Image",
    icon: <Image className="h-6 w-6" />,
    description: "Generate stunning images from text descriptions",
    path: "/image-generator",
    available: true
  },
  {
    title: "Background Remover",
    icon: <ImageOff className="h-6 w-6" />,
    description: "Remove backgrounds from your images instantly",
    path: "/background-remover",
    model: "background-remover",
    available: true
  },
  {
    title: "AI Security Audit",
    icon: <ShieldCheck className="h-6 w-6" />,
    description: "Smart contract security analysis and vulnerability detection",
    path: "/contract-audit",
    model: "contract-audit",
    available: true
  },
  {
    title: "Face Recognition Search Engine",
    icon: <Search className="h-6 w-6" />,
    description: "Advanced facial recognition search capabilities",
    path: "",
    available: false
  },
  {
    title: "DeFai",
    icon: <TrendingUp className="h-6 w-6" />,
    description: "AI-Powered DeFi for smarter trading and fund management",
    path: "",
    available: false
  },
  {
    title: "AI Agent Creator",
    icon: <Bot className="h-6 w-6" />,
    description: "Create and customize your own AI agents",
    path: "",
    available: false
  },
  {
    title: "My Points",
    icon: <Award className="h-6 w-6" />,
    description: "Complete tasks and earn points for exclusive rewards",
    path: "/points",
    available: true
  }
];

export default function LandingPage() {
  const [location, setLocation] = useLocation();

  const handleToolClick = (path: string, model?: ModelType) => {
    if (path) {
      setLocation(path);
    }
  };

  return (
    <div className="min-h-screen flex flex-col">
      {/* Unified Header */}
      <Header mode="landing" />

      {/* Main content */}
      <main className="flex-1 flex flex-col">
        <div className="container mx-auto max-w-4xl px-4 sm:px-6 flex-grow flex items-center mt-24 sm:mt-32 md:mt-28">
          <div className="w-full">
            <div className="text-center mb-10">
              <h2 className="text-2xl font-semibold mb-3">Select your advanced AI Tools</h2>
              <p className="text-sm text-muted-foreground">
                Built-in privacy and security for all your AI interactions
              </p>
            </div>

            <div className="grid grid-cols-1 sm:grid-cols-2 gap-4">
              {tools.map((tool) => (
                <div key={tool.title}>
                  {tool.available ? (
                    <Card
                      className="p-6 hover:bg-muted/50 cursor-pointer transition-colors h-full focus:outline-none focus:ring-0 active:ring-0"
                      onClick={() => handleToolClick(tool.path, tool.model as ModelType)}
                      tabIndex={-1} 
                    >
                      <div className="flex items-start gap-4">
                        <div className="text-foreground flex-shrink-0">
                          {tool.icon}
                        </div>
                        <div className="flex-1">
                          <h2 className="text-lg font-semibold">
                            {tool.title}
                          </h2>
                          <p className="text-sm text-muted-foreground mt-1">{tool.description}</p>
                        </div>
                        <ArrowRight className="h-4 w-4 flex-shrink-0 mt-1" />
                      </div>
                    </Card>
                  ) : (
                    <TooltipProvider>
                      <Tooltip>
                        <TooltipTrigger asChild>
                          <Card className="p-6 cursor-not-allowed bg-muted/20 hover:bg-muted/30 transition-colors h-full">
                            <div className="flex items-start gap-4">
                              <div className="text-muted-foreground flex-shrink-0">
                                {tool.icon}
                              </div>
                              <div className="flex-1">
                                <div className="flex items-center gap-2 flex-wrap">
                                  <h2 className="text-lg font-semibold text-muted-foreground">
                                    {tool.title}
                                  </h2>
                                  <span className="px-3 py-0.5 text-xs font-medium text-[#FFB20D] border border-muted rounded-full bg-muted/30">
                                    Coming Soon
                                  </span>
                                </div>
                                <p className="text-sm text-muted-foreground mt-1">{tool.description}</p>
                              </div>
                            </div>
                          </Card>
                        </TooltipTrigger>
                        <TooltipContent>
                          <p>This feature is coming soon!</p>
                        </TooltipContent>
                      </Tooltip>
                    </TooltipProvider>
                  )}
                </div>
              ))}
            </div>
          </div>
        </div>
        {/* Added mb-16 spacing to ensure there's always space before the footer on mobile */}
        <div className="mb-16 sm:mb-8 mt-auto"></div>
        <Footer />
      </main>
    </div>
  );
}